package FormValidator::LazyWay::Rule::DateTime::JA;

use strict;
use warnings;
use utf8;

sub datetime {'日時'}
sub date  {'日付'}
sub time {'時間'}

1;

=head1 NAME

FormValidator::LazyWay::Rule::DateTime::JA - Messages of DateTime Rule

=cut
