package FormValidator::LazyWay::Rule::Japanese::JA;

use strict;
use warnings;
use utf8;

sub hiragana {
    'ひらがな',
}

sub katakana {
    'カタカナ',
}
1;

=head1 NAME

FormValidator::LazyWay::Rule::Japanese::JA - Messages of Japanese Rule

=head1 METHOD

=head2 hiragana

=head2 katakana

=cut

